@@ -1,3 +1,6 @@
+#!/usr/bin/env bash
+set -euo pipefail
+
 #!/bin/bash
 set -e
 
